==> qastools_1.1.0.orig.tar.xz: qastools-v1.1.0/qasmixer/src/tray_mixer.hpp <==
/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#pragma once

#include <QIcon>
#include <QObject>
#include <memory>
#include <vector>

// Forward declaration
class Tray_Mixer_MDev_Setup;
class Tray_Mixer_View_Setup;
class Tray_Mixer_Balloon;
class Tray_Mixer_Icon;
namespace QSnd
{
class Mixer_Simple;
class Mixer_Simple_Elem;
} // namespace QSnd

/// @brief Tray_Mixer
///
class Tray_Mixer : public QObject
{
  Q_OBJECT

  // Public methods
  public:
  // -- Construction

  Tray_Mixer ( QObject * parent_n = nullptr );

  ~Tray_Mixer ();

  // -- Setup

  void
  set_mdev_setup ( Tray_Mixer_MDev_Setup * setup_n );

  void
  set_view_setup ( Tray_Mixer_View_Setup * setup_n );

  void
  update_balloon_setup ();

  bool
  is_visible () const;

  bool
  event ( QEvent * event_n ) override;

  // -- Public signals

  Q_SIGNAL
  void
  sig_toggle_mixer ();

  Q_SIGNAL
  void
  sig_quit ();

  // -- Protected slots
  protected:
  Q_SLOT
  void
  mixer_values_changed ();

  Q_SLOT
  void
  mixer_toggle_switch ();

  Q_SLOT
  void
  mouse_wheel_delta ( int wheel_delta_n );

  Q_SLOT
  void
  raise_balloon ();

  Q_SLOT
  void
  close_balloon ();

  // Private methods
  private:
  void
  init_icons ();

  void
  update_tray_icon ();

  bool
  update_volume_permille ();

  void
  update_volume_widgets ();

  void
  load_mixer ();

  void
  close_mixer ();

  // Private attributes
  private:
  Tray_Mixer_MDev_Setup * _mdev_setup;
  Tray_Mixer_View_Setup * _view_setup;

  // Mixer
  ::QSnd::Mixer_Simple * _snd_mixer;
  ::QSnd::Mixer_Simple_Elem * _mx_elem;
  unsigned int _volume_permille;

  // Icons and pixmaps
  /// 0: default
  /// 1: muted
  /// 2...: volumes
  unsigned int _icon_idx;
  ::std::vector< QIcon > _icons_volume;

  // State flags
  bool _volume_muted;
  bool _updating_scheduled;

  Tray_Mixer_Icon * _tray_icon;
  ::std::unique_ptr< Tray_Mixer_Balloon > _balloon;
};

==> qastools_1.2.0.orig.tar.xz: qastools-v1.2.0/qasmixer/src/tray_mixer.hpp <==
/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#pragma once

#include <QIcon>
#include <QObject>
#include <memory>
#include <vector>

// Forward declaration
class Tray_Mixer_MDev_Setup;
class Tray_Mixer_View_Setup;
class Tray_Mixer_Balloon;
class Tray_Mixer_Icon;
namespace QSnd::Mixer
{
class Elem;
class Mixer;
} // namespace QSnd::Mixer
namespace dpe
{
class Image_Allocator;
}

/// @brief Tray_Mixer
///
class Tray_Mixer : public QObject
{
  Q_OBJECT

  public:
  // -- Construction

  Tray_Mixer ( dpe::Image_Allocator * image_alloc_n,
               QObject * parent_n = nullptr );

  ~Tray_Mixer ();

  // -- Setup

  void
  set_mdev_setup ( Tray_Mixer_MDev_Setup * setup_n );

  void
  set_view_setup ( Tray_Mixer_View_Setup * setup_n );

  void
  update_balloon_setup ();

  bool
  is_visible () const;

  bool
  event ( QEvent * event_n ) override;

  // -- Public signals

  Q_SIGNAL
  void
  sig_toggle_mixer ();

  Q_SIGNAL
  void
  sig_quit ();

  // -- Protected slots
  protected:
  Q_SLOT
  void
  mixer_values_changed ();

  Q_SLOT
  void
  mixer_toggle_switch ();

  Q_SLOT
  void
  mouse_wheel_delta ( int wheel_delta_n );

  Q_SLOT
  void
  raise_balloon ();

  Q_SLOT
  void
  close_balloon ();

  private:
  // -- Private methods

  void
  init_icons ();

  void
  update_tray_icon ();

  bool
  update_volume_permille ();

  void
  update_volume_widgets ();

  void
  load_mixer ();

  void
  close_mixer ();

  private:
  // -- Attributes
  Tray_Mixer_MDev_Setup * _mdev_setup = nullptr;
  Tray_Mixer_View_Setup * _view_setup = nullptr;
  dpe::Image_Allocator * _image_alloc = nullptr;

  // Mixer
  QSnd::Mixer::Mixer * _snd_mixer = nullptr;
  QSnd::Mixer::Elem * _mx_elem = nullptr;
  unsigned int _volume_permille;

  // Icons and pixmaps
  /// 0: default
  /// 1: muted
  /// 2...: volumes
  unsigned int _icon_idx;
  std::vector< QIcon > _icons_volume;

  // State flags
  bool _volume_muted;
  bool _updating_scheduled;

  Tray_Mixer_Icon * _tray_icon;
  std::unique_ptr< Tray_Mixer_Balloon > _balloon;
};
